@@ -39,7 +39,14 @@ pub fn minify(src: &[u8], cfg: &Cfg) -> Vec<u8> {
     let mut code = Code::new(src);
     let parsed = parse_content(&mut code, Namespace::Html, EMPTY_SLICE, EMPTY_SLICE);
     let mut out = Vec::with_capacity(src.len());
-    minify_content(cfg, &mut out, false, EMPTY_SLICE, parsed.children);
+    minify_content(
+        cfg,
+        &mut out,
+        Namespace::Html,
+        false,
+        EMPTY_SLICE,
+        parsed.children,
+    );
     out
 }
 
